"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils/utils");
/**
 * Sets up a middleware which allows plugins to transform files before they are served to the browser.
 */
function createPluginTransformMiddlware(cfg) {
    const transformPlugins = cfg.plugins.filter(p => 'transform' in p);
    if (transformPlugins.length === 0) {
        // nothing to transform
        return (ctx, next) => next();
    }
    return async function pluginTransformMiddleware(context, next) {
        var _a;
        await next();
        if (context.status < 200 || context.status >= 300) {
            return undefined;
        }
        if (!utils_1.isUtf8(context)) {
            return undefined;
        }
        // responses are streams initially, but to allow transforming we turn it
        // into a string first
        try {
            context.body = await utils_1.getBodyAsString(context);
        }
        catch (error) {
            if (error instanceof utils_1.RequestCancelledError) {
                return undefined;
            }
            return undefined;
        }
        for (const plugin of transformPlugins) {
            const response = await ((_a = plugin.transform) === null || _a === void 0 ? void 0 : _a.call(plugin, context));
            if (response) {
                if (response.body != null) {
                    context.body = response.body;
                }
                if (response.headers) {
                    for (const [k, v] of Object.entries(response.headers)) {
                        context.response.set(k, v);
                    }
                }
            }
        }
    };
}
exports.createPluginTransformMiddlware = createPluginTransformMiddlware;
//# sourceMappingURL=plugin-transform.js.map